FileSystem

Struct FileSystem 

pub struct FileSystem { /* private fields */ }

Implementations

Source

impl FileSystem

pub fn new() -> Self

pub fn get_base_path(&self) -> PathBuf

pub fn add_file( &mut self, disk_path: PathBuf, virtual_path: &PathBuf, virtual_is_file: bool, as_bytes: bool, ) -> Option<usize>

Create a file in the filesystem. If the file already exists, this function will return None.

  • disk_path - Path to file on the hosts system.
  • virtual_path - Internal path representation.
  • virtual_is_file - If [virtual_path] contains a filename.
  • as_bytes - Should the file be loaded into a byte array?
pub fn code(&self, canonicalize: bool) -> String

Generates standalone code representing the filesystem.