pub struct FileSystem { /* private fields */ }Implementations
Sourceimpl FileSystem
impl FileSystem
pub fn new() -> Self
pub fn get_base_path(&self) -> PathBuf
Sourcepub fn add_file(
&mut self,
disk_path: PathBuf,
virtual_path: &PathBuf,
virtual_is_file: bool,
as_bytes: bool,
) -> Option<usize>
pub fn add_file( &mut self, disk_path: PathBuf, virtual_path: &PathBuf, virtual_is_file: bool, as_bytes: bool, ) -> Option<usize>
Create a file in the filesystem.
If the file already exists, this function will return None.
disk_path- Path to file on the hosts system.virtual_path- Internal path representation.virtual_is_file- If [virtual_path] contains a filename.as_bytes- Should the file be loaded into a byte array?